@@ -5,8 +5,9 @@ dir_path = os.path.dirname(os.path.realpath(__file__))
 
 def _getcsv(name):
     def fn():
-        return pd.read_csv(f"{dir_path}/{name}.csv")
+        return pd.read_csv(f"{dir_path}/data/{name}.csv")
     return fn
 
 countries = _getcsv('countries')
-airbnb = _getcsv('airbnb')
\ No newline at end of file
+airbnb = _getcsv('airbnb')
+corona = _getcsv('corona')
\ No newline at end of file
